=============
pankoclient
=============

Python bindings to the OpenStack Panko API

This is a client for OpenStack Panko API. There's :doc:`a Python API
<api>` (the :mod:`pankoclient` module), and a :doc:`command-line script
<shell>` (installed as :program:`panko`). Each implements the entire
OpenStack Panko API.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/python-pankoclient
* Source: http://git.openstack.org/cgit/openstack/python-pankoclient
* Bugs: http://bugs.launchpad.net/python-pankoclient
